##  Advantages
  * Complexity is minimized as developers no longer have to understand the SAP LeanIX data model
  * Configuration for SAP LeanIX is contained in every connector
  * No longer having to map logic inside of code
  * Integration now possible even if the external system does not allow direct access
  * No need for a direct REST connection
  * Flexible error handling, no failure due to a single or even multiple data issues. Data that does not meet the requirements, is simply ignored
  * Cross-cutting concerns are part of the API and in each connector
